pys
===

Miscellaneous pythons 🐍

Install
-------

We on pypi now, so install by `pip install pys`.

For installing locally,

    git pull https://github.com/noobermin/pys.git
    cd pys
    pip install . --user


Documentation
-------------
    >>> import pys
    >>> help(pys)
    
or

    >>> from pys import herp
    >>> help(herp)

For more details, from the `pys` directory,

    cd pys
    cat __init__.py

`less` is another similar command but has this amazing feature of allowing pagination.